@@ -1,7 +1,8 @@
 <html>
-<!--nobanner-->
+<head>
 <title><?cs var:Subject ?></title>
-<base href="<?cs var:html_escape(RCGIURI) ?>/<?cs if:BBS ?><?cs var:html_escape(BBS) ?>/<?cs /if ?><?cs if:KEY ?><?cs var:html_escape(KEY) ?>/<?cs /if ?><?cs if:BaseQueryString ?>!<?cs var:html_escape(QueryString) ?>/<?cs /if ?><?cs var:html_escape(RawOption) ?>">
+<meta http-equiv=Content-Type content="text/html;charset=sjis">
+<base href="<?cs var:html_escape(RCGIURI) ?>/<?cs if:BBS ?><?cs var:html_escape(BBS) ?>/<?cs /if ?><?cs if:KEY ?><?cs var:html_escape(KEY) ?>/<?cs /if ?><?cs if:BaseQueryString ?><?cs var:html_escape(QueryString) ?>/<?cs /if ?><?cs var:html_escape(RawOption) ?>">
 </head>
 <body
 <?cs if:TextColor ?> text=#<?cs var:html_escape(TextColor) ?><?cs /if ?>
@@ -15,10 +16,10 @@
 <a name=u></a>
 <?cs if:Write ?>
 <?cs if:WriteForm ?>
-<hr><form method=post action=<?cs var:html_escape(CGIURI) ?>/bbs.cgi utn>
+<form method=post action=<?cs var:html_escape(CGIURI) ?>/bbs.cgi?guid=on>
 <input type=hidden name=key value=<?cs var:html_escape(KEY) ?>>
-<input name=FROM size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(NameByCookie) ?><?cs /if ?>><br>
-<input name=mail size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(MailByCookie) ?><?cs /if ?>><br>
+<input name=FROM size=14<?cs if:NameByCookie ?> value="<?cs var:html_escape(NameByCookie) ?>"<?cs /if ?>><br>
+<input name=mail size=14<?cs if:NameByCookie ?> value="<?cs var:html_escape(MailByCookie) ?>"<?cs /if ?>><br>
 <textarea name=MESSAGE></textarea><br><input type=submit value= accesskey=4>
 <input type=hidden name=bbs value=<?cs var:html_escape(BBS) ?>>
 <input type=hidden name=time value=<?cs var:html_escape(TimeStamp) ?>>
@@ -32,31 +33,30 @@
 <hr>
 <form action=SET>
 <input name=mode type=hidden value=SET>\ݒ脟<br>
-<input type=checkbox name=1a value=1 checked>ftHgAAS<br>
-<!--<input type=checkbox name=2a value="on" checked>Xp<br>-->
-<!--<input type=checkbox name=3a value="on" checked>IDo<br>-->
-<input type=checkbox name=1b value=on>ȗ<br>
-X<input name=THREAD size=4 istyle=1 value=30>\<br>
-X<input name=RES size=4 istyle=4 value=10>\<br>
-X<input name=LINE size=4 istyle=4 value=10>sŏȗ<br>
-ftHg<br>
-:<input name=FROM size=14 value=><br>
-:<input name=mail size=14 istyle=4 value=><br>
+<input type=checkbox name=1a value=1<?cs if:AAS ?> checked<?cs /if ?>>̫AAS<br>
+<input type=checkbox name=1b value=1<?cs if:OmitDefaultName ?> checked<?cs /if ?>>ȗ<br>
+<input type=checkbox name=t value=1<?cs if:Thumbnail ?> checked<?cs /if ?>>Ȳ<br>
+<input name=THREAD size=4 istyle=1 value=30>\<br>
+ڽ<input name=RES size=4 istyle=4 value=10>\<br>
+ڽ<input name=LINE size=4 istyle=4 value=10>sŏȗ<br>
+̫ď<br>
+:<input name=FROM size=14<?cs if:NameByCookie ?> value="<?cs var:html_escape(NameByCookie) ?>"<?cs /if ?>><br>
+:<input name=mail size=14 istyle=4<?cs if:NameByCookie ?> value="<?cs var:html_escape(MailByCookie) ?>"<?cs /if ?>><br>
 <input type=submit value=>
 <hr>
-HTMLXL(zF)<br>
+HTML(zF)<br>
 :#<input name=txt size=14 istyle=4 value=<?cs if:TextColor ?><?cs var:html_escape(TextColor) ?><?cs else ?>000000<?cs /if ?>><br>
 wi:#<input name=bgc size=14 istyle=4 value=<?cs if:BackGroundColor ?><?cs var:html_escape(BackGroundColor) ?><?cs else ?>efefef<?cs /if ?>><br>
-N:#<input name=link size=14 istyle=4 value=<?cs if:LinkColor ?><?cs var:html_escape(LinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
-ǃN:#<input name=vlink size=14 istyle=4 value=<?cs if:VLinkColor ?><?cs var:html_escape(VLinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
-NbN:#<input name=alink size=14 istyle=4 value=<?cs if:ALinkColor ?><?cs var:html_escape(ALinkColor) ?><?cs else ?>FFFFFF<?cs /if ?>><br>
-TCY:<input name=size size=14 istyle=4 value=<?cs if:Fontsize ?><?cs var:html_escape(Fontsize) ?><?cs else ?>3<?cs /if ?>><br>
+ݸ:#<input name=link size=14 istyle=4 value=<?cs if:LinkColor ?><?cs var:html_escape(LinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
+ݸ:#<input name=vlink size=14 istyle=4 value=<?cs if:VLinkColor ?><?cs var:html_escape(VLinkColor) ?><?cs else ?>0000FF<?cs /if ?>><br>
+د:#<input name=alink size=14 istyle=4 value=<?cs if:ALinkColor ?><?cs var:html_escape(ALinkColor) ?><?cs else ?>FFFFFF<?cs /if ?>><br>
+:<input name=size size=14 istyle=4 value=<?cs if:Fontsize ?><?cs var:html_escape(Fontsize) ?><?cs else ?>3<?cs /if ?>><br>
 <input type=submit value=>
 </form><hr>
 <a name=d></a>
 <a href="SET#u" accesskey=2></a>
 <?cs elif:SettingSaved ?>
-ݒ芮<br><a href="./!<?cs var:html_escape(QueryString) ?>/i">ubN}[NĂ</a>B
+ݒ芮<br><a href="./<?cs var:html_escape(QueryString) ?>/i">ޯϰĂ</a>B
 </html>
 <?cs /if ?>
 <?cs else ?>
@@ -65,16 +65,16 @@ TCY:<input name=size size=14 istyle=4 value=<?cs if:Fontsize ?><?cs var:html_esc
 <?cs if:Copy ?>
 <hr><?cs each:item = Thread ?>
 <form action=i><textarea>
-<?cs var:html_escape(item.index) ?>:<?cs var:item.name ?><?cs var:html_escape(item.date) ?>
+<?cs var:html_escape(item.resno) ?>:<?cs var:html_escape(item.name) ?> <?cs var:item.date ?>
 <?cs if:item.mail ?>
  [<?cs var:html_escape(item.mail) ?>]
  <?cs /if ?>
-<?cs var:CR ?><?cs var:item.text ?>
+<?cs var:CR ?><?cs var:html_escape(item.textNT) ?>
 </textarea><br>
 <?cs /each ?><br>
 <?cs else ?>
 <?cs each:item = Thread ?>
-<hr><?cs var:html_escape(item.resno) ?>:<b><?cs var:item.name ?></b><?cs var:html_escape(item.date) ?>
+<hr><?cs var:html_escape(item.resno) ?>:<b><?cs var:item.name ?></b><?cs var:item.date ?>
 <?cs if:item.mail ?>
  [<?cs var:html_escape(item.mail) ?>]
  <?cs /if ?>
@@ -95,10 +95,11 @@ TCY:<input name=size size=14 istyle=4 value=<?cs if:Fontsize ?><?cs var:html_esc
 <a href=1-<?cs if:AAS ?>a<?cs /if ?> accesskey=1>1-</a>
 <a href=n<?cs if:AAS ?>a<?cs /if ?><?cs if:Copy ?>c<?cs /if ?> accesskey=3>V</a>
 <a href=w accesskey=4></a>
-<a href=<?cs var:html_escape(RawOption) ?><?cs if:!Copy ?>c<?cs /if ?> accesskey=5></a>
-<a href=../<?cs if:QueryString ?>../!<?cs var:html_escape(QueryString) ?>/<?cs /if ?> accesskey=6></a>
-<a href=<?cs var:html_escape(RawOption) ?><?cs if:!AAS ?>a<?cs /if ?>>AA</a>
+<a href=<?cs var:html_escape(RawOptionNoC) ?><?cs if:!Copy ?>c<?cs /if ?> accesskey=5></a>
+<a href=../<?cs if:BaseQueryString ?>../<?cs var:html_escape(QueryString) ?>/<?cs /if ?> accesskey=6></a>
+<a href=<?cs var:html_escape(RawOptionNoA) ?><?cs if:!AAS ?>a<?cs /if ?>>AA</a>
 <a href=SET accesskey=#></a>
+<a href=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?m=1></a>
 <?cs if:BBS_ACCEPT_MAILPOST ?>
 <br><a href=<?cs var:html_escape(CGIURI) ?>/m.cgi/<?cs var:html_escape(BBS) ?>/>X</a>
 (<a href=mailto:<?cs var:MailPostAddress ?>?
