@@ -67,7 +67,7 @@ function redir(element) {
 <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">zXbhǗ</a><?cs /if ?>
 <br>
 <select name="key">
-<?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"<?cs if:item.selected ?> selected<?cs /if ?>><?cs var:html_escape(item.subject) ?> (<?cs var:html_escape(item.res) ?>)</option>
+<?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"<?cs if:item.selected ?> selected<?cs /if ?>><?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</option>
 <?cs /each ?></select><br>
 <table border="0">
 <tr><td><label for="it_resno">Xԍ</label></td><td><input id="it_resno" name="resno" type="text" value="<?cs var:html_escape(Resno) ?>" size="5"></td></tr>
