@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Host.pm 1201 2007-09-28 14:36:30Z hikarin $
+# $Id: Host.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Img0ch::Plugin::Filter::Host;
@@ -36,6 +36,14 @@ sub check {
             $iApp->set_error('POST_FROM_DENIED_HOST');
             return 0;
         }
+        if ( $iApp->request()->get_header('user-agent')
+            =~ /p2-user-hash:\s*(\w+)/ )
+        {
+            if ( !$iFRH->write_ok($1) ) {
+                $iApp->set_error('POST_FROM_DENIED_HOST');
+                return 0;
+            }
+        }
     }
     return 1;
 }
