@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 1976 2010-01-23 15:50:07Z hikarin $
+# $Id: Install.pm 2002 2010-02-21 13:28:07Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -264,9 +264,7 @@ sub install {
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::XCSV',
-            methods => {
-                repair   => 'zeromin.repair.upload',
-            },
+            methods => { repair => 'zeromin.repair.upload', },
         }
     );
     return 1;
@@ -311,9 +309,7 @@ sub uninstall {
     );
     $zPlugin->uninstall(
         {   package => 'Img0ch::Plugin::Upload::XCSV',
-            methods => {
-                generate => 'bbs.upload.post',
-            },
+            methods => { generate => 'bbs.upload.post', },
         }
     );
     return 1;
