@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Subject.pm 923 2007-07-26 13:35:24Z hikarin $
+# $Id: Subject.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Img0ch::Pool::Subject;
@@ -56,11 +56,11 @@ sub get {
 }
 
 sub get_utf8 {
-    my ( $iPool, $key ) = @_;
-    my ( $subject, $res )  = @{ $iPool->get($key) };
+    my ( $iPool,   $key ) = @_;
+    my ( $subject, $res ) = @{ $iPool->get($key) };
 
-    $subject = $iPool->{_kernel}->get_encoded_str(
-        $subject, 'utf8', $iPool->{_encoding} );
+    $subject = $iPool->{_kernel}
+        ->get_encoded_str( $subject, 'utf8', $iPool->{_encoding} );
 
     return [ $subject, $res ];
 }
