@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: NGWord.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: NGWord.pm 1957 2010-01-23 11:18:01Z hikarin $
 #
 
 package Zeromin::Filter::NGWord;
@@ -22,7 +22,6 @@ package Zeromin::Filter::NGWord;
 use strict;
 use base qw(Img0ch::Filter::NGWord);
 use Digest::MD5 qw();
-use ShiftJIS::Regexp qw();
 
 sub new {
     my ( $zClass, $iObject ) = @_;
@@ -35,7 +34,7 @@ sub new {
         $zFNG->{__bbs_id} = $iObject->get_id();
         $zFNG->{__kernel} = $iKernel;
     }
-    elsif ( $class eq 'Img0ch::Maple' ) {
+    elsif ( $class eq 'Img0ch::Kernel' or $class eq 'Img0ch::Maple' ) {
         require Img0ch::BBS;
         $iKernel = $iObject;
         my $iBBS = Img0ch::BBS->new( $iKernel, { id => 0 } );
@@ -67,8 +66,12 @@ sub save {
         my $word   = $one->[0];
         my $id     = Digest::MD5::md5_hex( $bbs, $word );
         my $prefix = "${prefix_top}.${id}";
+        eval { $iRepos->set_binary( "${prefix}.regex", qr{$word} ); };
+        if ($@) {
+            $iRepos->set_binary( "${prefix}.regex", $word );
+        }
         $iRepos->set_binary( "${prefix}.entry", $word );
-        $iRepos->set_binary( "${prefix}.regex", ShiftJIS::Regexp::re($word) );
+        $iRepos->set( "${prefix}.utf8", 1 );
         $iRepos->set( "${prefix}.flag", $one->[1] );
         $iRepos->set_binary( "${prefix}.replace", $one->[2] );
         $iRepos->set( "${prefix}.apply", $one->[3] );
@@ -97,7 +100,7 @@ sub get {
         my $prefix = "I:F:N.${bbs}.${id_hex}";
         my $entry  = $iRepos->get_binary("${prefix}.entry");
         my $to     = $iRepos->get_binary("${prefix}.replace");
-        if ($unijp) {
+        if ( $unijp and !$iRepos->get("${prefix}.utf8") ) {
             $entry = $unijp->set( $entry, 'sjis' )->get();
             $to    = $unijp->set( $to,    'sjis' )->get();
         }
@@ -115,7 +118,7 @@ sub get {
         my $prefix = "I:F:N.${bbs}.${id_b64}";
         my $entry  = $iRepos->get_binary("${prefix}.entry");
         my $to     = $iRepos->get_binary("${prefix}.replace");
-        if ($unijp) {
+        if ( $unijp and !$iRepos->get("${prefix}.utf8") ) {
             $entry = $unijp->set( $entry, 'sjis' )->get();
             $to    = $unijp->set( $to,    'sjis' )->get();
         }
@@ -218,13 +221,13 @@ sub set {
         my $prev_to   = $iRepos->decode_binary(
             $iRepos->remove("${prev_prefix}.replace") );
         my $prev_apply = $iRepos->remove("${prev_prefix}.apply");
-        my $new = Digest::MD5::md5_hex( $bbs, $word );
-        my $pfx = "I:F:N.${bbs}.${new}";
+        my $new        = Digest::MD5::md5_hex( $bbs, $word );
+        my $pfx        = "I:F:N.${bbs}.${new}";
         $iRepos->set_binary( "${pfx}.entry", $word );
         $iRepos->set_binary( "${pfx}.regex", $regex );
-        $iRepos->set( "${pfx}.flag",           ( $type || $prev_type ) );
-        $iRepos->set_binary( "${pfx}.replace", ( $to   || $prev_to ) );
-        $iRepos->set( "${pfx}.apply", ( $apply || $prev_apply ) );
+        $iRepos->set( "${pfx}.flag",           ( $type  || $prev_type ) );
+        $iRepos->set_binary( "${pfx}.replace", ( $to    || $prev_to ) );
+        $iRepos->set( "${pfx}.apply",          ( $apply || $prev_apply ) );
         return 1;
     }
 
